==> lumina-1.3.0_p1.tar.gz: lumina-1.3.0-p1/src-qt5/desktop-utils/lumina-screenshot/i18n/l-screenshot_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>ImageEditor</name>
    <message>
        <location filename="../ImageEditor.cpp" line="14"/>
        <source>Zoom In</source>
        <translation>Didinti</translation>
    </message>
    <message>
        <location filename="../ImageEditor.cpp" line="15"/>
        <source>Zoom Out</source>
        <translation>Mažinti</translation>
    </message>
</context>
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="529"/>
        <source>Take Screenshot</source>
        <translation>Padaryti ekrano kopiją</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="422"/>
        <source>Include Borders</source>
        <translation>Įtraukti rėmelį</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="540"/>
        <source>Save As</source>
        <translation>Įrašyti kaip</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="138"/>
        <source>Resize</source>
        <translation>Keisti dydį</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="20"/>
        <source>Lumina Screenshot</source>
        <translation>Lumina ekrano kopija</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="87"/>
        <source>Open screenshot with an application</source>
        <translation>Atverti ekrano kopiją, naudojant programą</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="90"/>
        <source>Open</source>
        <translation>Atverti</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="103"/>
        <source>Copy screenshot to clipboard</source>
        <translation>Kopijuoti ekrano kopiją į iškarpinę</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="106"/>
        <source>Copy</source>
        <translation>Kopijuoti</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="109"/>
        <source>Ctrl+C</source>
        <translation>Ctrl(Vald)+C</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="135"/>
        <source>Resize screenshot to selection</source>
        <translation>Pakeisti ekrano kopijos dydį iki žymėjimo</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="157"/>
        <source>Crop screenshot to selection</source>
        <translation>Apkirpti ekrano kopiją iki žymėjimo</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="160"/>
        <source>&amp;Crop</source>
        <translation>&amp;Apkirpti</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="293"/>
        <source>Screen Capture Settings</source>
        <translation>Ekrano fotografavimo nustatymai</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="341"/>
        <source> Sec Delay</source>
        <translation> sek. delsa</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="433"/>
        <source>Select Area</source>
        <translation>Žymėti sritį</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="445"/>
        <source>General Settings</source>
        <translation>Bendri nustatymai</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="466"/>
        <source>Show popup warnings about unsaved screenshots</source>
        <translation>Rodyti iškylančiuosius įspėjimus apie neįrašytas ekrano kopijas</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="499"/>
        <source>toolBar</source>
        <translation>Įrankių juosta</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="526"/>
        <source>Capture</source>
        <translation>Fotografuoti</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="532"/>
        <source>Ctrl+N</source>
        <translation>Ctrl(Vald)+N</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="556"/>
        <source>Close</source>
        <translation>Užverti</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="559"/>
        <source>Close Application</source>
        <translation>Užverti programą</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="562"/>
        <source>Esc</source>
        <translation>Esc(Gr)</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="328"/>
        <source>Entire Session</source>
        <translation>Visas seansas</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="409"/>
        <source>Single Window</source>
        <translation>Vienas langas</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="370"/>
        <source>Single Screen</source>
        <translation>Vienas ekranas</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="39"/>
        <source>View</source>
        <translation>Rodinys</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="40"/>
        <source>Settings</source>
        <translation>Nustatymai</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="103"/>
        <source>Could not save screenshot</source>
        <translation>Nepavyko įrašyti ekrano kopijos</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="103"/>
        <source>The screenshot could not be saved. Please check directory permissions or pick a different directory</source>
        <translation>Nepavyko įrašyti ekrano kopiją. Prašome patikrinti katalogo leidimus arba pasirinkti kitą katalogą</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="120"/>
        <source>Save Screenshot</source>
        <translation>Įrašyti ekrano kopiją</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="322"/>
        <source>Unsaved Screenshot</source>
        <translation>Neįrašyta ekrano kopija</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="323"/>
        <source>The current screenshot has not been saved yet. Do you want to save or discard your changes?</source>
        <translation>Esama ekrano kopija kol kas nebuvo neįrašyta. Norite įrašyti ar atmesti savo pakeitimus?</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="543"/>
        <source>Ctrl+S</source>
        <translation>Ctrl(Vald)+S</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="551"/>
        <source>Quick Save</source>
        <translation>Greitasis įrašymas</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="120"/>
        <source>PNG Files (*.png);;AllFiles (*)</source>
        <translation>PNG failai (*.png);;Visi failai (*)</translation>
    </message>
</context>
</TS>

==> lumina-1.4.0_p1.tar.gz: lumina-1.4.0-p1/src-qt5/desktop-utils/lumina-screenshot/i18n/l-screenshot_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>ImageEditor</name>
    <message>
        <location filename="../ImageEditor.cpp" line="14"/>
        <source>Zoom In</source>
        <translation>Didinti</translation>
    </message>
    <message>
        <location filename="../ImageEditor.cpp" line="15"/>
        <source>Zoom Out</source>
        <translation>Mažinti</translation>
    </message>
</context>
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="529"/>
        <source>Take Screenshot</source>
        <translation>Padaryti ekrano kopiją</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="422"/>
        <source>Include Borders</source>
        <translation>Įtraukti rėmelį</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="540"/>
        <source>Save As</source>
        <translation>Įrašyti kaip</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="138"/>
        <source>Resize</source>
        <translation>Keisti dydį</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="20"/>
        <source>Lumina Screenshot</source>
        <translation>Lumina ekrano kopija</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="87"/>
        <source>Open screenshot with an application</source>
        <translation>Atverti ekrano kopiją, naudojant programą</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="90"/>
        <source>Open</source>
        <translation>Atverti</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="103"/>
        <source>Copy screenshot to clipboard</source>
        <translation>Kopijuoti ekrano kopiją į iškarpinę</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="106"/>
        <source>Copy</source>
        <translation>Kopijuoti</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="109"/>
        <source>Ctrl+C</source>
        <translation>Ctrl(Vald)+C</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="135"/>
        <source>Resize screenshot to selection</source>
        <translation>Pakeisti ekrano kopijos dydį iki žymėjimo</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="157"/>
        <source>Crop screenshot to selection</source>
        <translation>Apkirpti ekrano kopiją iki žymėjimo</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="160"/>
        <source>&amp;Crop</source>
        <translation>&amp;Apkirpti</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="293"/>
        <source>Screen Capture Settings</source>
        <translation>Ekrano fotografavimo nustatymai</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="341"/>
        <source> Sec Delay</source>
        <translation> sek. delsa</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="433"/>
        <source>Select Area</source>
        <translation>Žymėti sritį</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="445"/>
        <source>General Settings</source>
        <translation>Bendri nustatymai</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="466"/>
        <source>Show popup warnings about unsaved screenshots</source>
        <translation>Rodyti iškylančiuosius įspėjimus apie neįrašytas ekrano kopijas</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="526"/>
        <source>Capture</source>
        <translation>Fotografuoti</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="532"/>
        <source>Ctrl+N</source>
        <translation>Ctrl(Vald)+N</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="556"/>
        <source>Close</source>
        <translation>Užverti</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="559"/>
        <source>Close Application</source>
        <translation>Užverti programą</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="562"/>
        <source>Esc</source>
        <translation>Esc(Gr)</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="328"/>
        <source>Entire Session</source>
        <translation>Visas seansas</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="409"/>
        <source>Single Window</source>
        <translation>Vienas langas</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="370"/>
        <source>Single Screen</source>
        <translation>Vienas ekranas</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="39"/>
        <source>View</source>
        <translation>Rodinys</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="40"/>
        <source>Settings</source>
        <translation>Nustatymai</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="103"/>
        <source>Could not save screenshot</source>
        <translation>Nepavyko įrašyti ekrano kopijos</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="103"/>
        <source>The screenshot could not be saved. Please check directory permissions or pick a different directory</source>
        <translation>Nepavyko įrašyti ekrano kopiją. Prašome patikrinti katalogo leidimus arba pasirinkti kitą katalogą</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="120"/>
        <source>Save Screenshot</source>
        <translation>Įrašyti ekrano kopiją</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="325"/>
        <source>Unsaved Screenshot</source>
        <translation>Neįrašyta ekrano kopija</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="326"/>
        <source>The current screenshot has not been saved yet. Do you want to save or discard your changes?</source>
        <translation>Esama ekrano kopija kol kas nebuvo neįrašyta. Norite įrašyti ar atmesti savo pakeitimus?</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="329"/>
        <source>Save</source>
        <translation>Įrašyti</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="330"/>
        <source>Discard</source>
        <translation>Atmesti</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="331"/>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="543"/>
        <source>Ctrl+S</source>
        <translation>Ctrl(Vald)+S</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="551"/>
        <source>Quick Save</source>
        <translation>Greitasis įrašymas</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="120"/>
        <source>PNG Files (*.png);;AllFiles (*)</source>
        <translation>PNG failai (*.png);;Visi failai (*)</translation>
    </message>
</context>
<context>
    <name>XDGDesktopList</name>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="608"/>
        <source>Multimedia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="609"/>
        <source>Development</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="610"/>
        <source>Education</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="611"/>
        <source>Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="612"/>
        <source>Graphics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="613"/>
        <source>Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="614"/>
        <source>Office</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="615"/>
        <source>Science</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="616"/>
        <source>Settings</source>
        <translation type="unfinished">Nustatymai</translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="617"/>
        <source>System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="618"/>
        <source>Utility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="619"/>
        <source>Wine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="620"/>
        <source>Unsorted</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
